Contact | When Geeks Wed

Home Contact

# Contact

Tips, Product Reviews and Giveaways:

Have a tip for When Geeks Wed, a product you would like reviewed or a giveaway idea?

Advertisers:

Thank you for your interest in advertising on When Geeks Wed! I look forward to working with you in the form of banner advertising or sponsored posts. We do not accept text links, so please don’t contact us about those initiatives.

General Questions:

Have a question for When Geeks Wed?

Your Name (required)

Your Email (required)

Subject (required)

Your Message

Due to the high volume of emails it may take a few weeks for a response and I thank you in advance for your patience. If you still haven’t heard back, your email may have gotten lost, please feel free to send a follow-up email I’ll try to respond as soon as I can.

#### WGW Community

28,565 Fans
3.6K
2.9K
447
21K

### Storm Inspiration Board

Aug 10, 2015

### Sailor Chibi Moon Inspiration Board

Jan 27, 2015

### Poison Ivy Inspiration Board

Jun 29, 2014

### Frozen Elsa Inspiration Board

Feb 3, 2014

### Finn Adventure Time Inspiration Board

Dec 27, 2013
8 Bit Adventure Time Alice In Wonderland Avengers Back To The Future Batman Captain America Comic Con Comics Cosplay Day Of The Dead Disney Doctor Who Fairy Tales Final Fantasy Game Of Thrones Geeky Valentines Gothic Halloween Harry Potter Hunger Games Indiana Jones Iron Man Lego Lord Of The Rings Mass Effect Minecraft Nightmare Before Christmas Pokemon Portal Punk Rock Robots Star Trek Star Wars Steampunk Super Mario Bros Superhero The Hobbit Tim Burton Transformers Video Games Wonder Woman World of Warcraft Zelda Zombies